summaryrefslogtreecommitdiff
path: root/ubuntu/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'ubuntu/scripts')
-rwxr-xr-xubuntu/scripts/netperf-client.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/ubuntu/scripts/netperf-client.sh b/ubuntu/scripts/netperf-client.sh
index 370a8fe..aadfc94 100755
--- a/ubuntu/scripts/netperf-client.sh
+++ b/ubuntu/scripts/netperf-client.sh
@@ -27,8 +27,8 @@ fi
ifconfig -a
ping -c 1 ${remote_ip} || exit 1
-ping -c 30 ${remote_ip} | ./scripts/netperf2LAVA.py
-for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -c -C -- -m $m -D; done | ./scripts/netperf2LAVA.py
-for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -t UDP_STREAM -c -C -- -m $m -D; done | ./scripts/netperf2LAVA.py
-for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t TCP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./scripts/netperf2LAVA.py
-for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t UDP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./scripts/netperf2LAVA.py
+ping -c 30 ${remote_ip} | ./ubuntu/scripts/netperf2LAVA.py
+for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -c -C -- -m $m -D; done | ./ubuntu/scripts/netperf2LAVA.py
+for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -t UDP_STREAM -c -C -- -m $m -D; done | ./ubuntu/scripts/netperf2LAVA.py
+for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t TCP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./ubuntu/scripts/netperf2LAVA.py
+for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t UDP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./ubuntu/scripts/netperf2LAVA.py